﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace ExpandChild
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private ObservableCollection<TreeData> treeData = null;
        public MainWindow()
        {
            InitializeComponent();
            this.treeData = new ObservableCollection<TreeData>(TreeData.GenerateTreeData());
            treeGrid.DataContext = this.treeData;            
        }

        private void treeGrid_RecordExpanding(object sender, Infragistics.Windows.DataPresenter.Events.RecordExpandingEventArgs e)
        {
            // For example, you can cancel firing the RecordExpanded event or 
            // perform some other logic before adding the child in the RecordExpanded event
        }   

        void treeGrid_RecordExpanded(object sender, Infragistics.Windows.DataPresenter.Events.RecordExpandedEventArgs e)
        {
            int parentRecordIndex = e.Record.Index;
            int childrenCount = this.treeData[parentRecordIndex].Children.Count;

            int newChildRecordIndex = parentRecordIndex + childrenCount;
            this.treeData[parentRecordIndex].Children.Add(
                new TreeData { ID = newChildRecordIndex, Name = "Row " + parentRecordIndex + " " + childrenCount });
        }     
    }
    public class TreeData : PropertyChangedNotifier
    {

        public TreeData()
        {
        }

        private int id;

        public int ID
        {
            get { return id; }
            set { id = value; OnPropertyChagned("ID"); }
        }

        private string name;

        public string Name
        {
            get { return name; }
            set { name = value; OnPropertyChagned("Name"); }
        }

        private ObservableCollection<TreeData> children;

        public ObservableCollection<TreeData> Children
        {
            get { return children; }
            set
            {
                children = value;
                OnPropertyChagned("Children");
            }
        }

        public static ObservableCollection<TreeData> GenerateTreeData()
        {
            ObservableCollection<TreeData> data = new ObservableCollection<TreeData>();
            for (int i = 0; i < 2; i++)
            {
                TreeData n = new TreeData
                {
                    ID = i,
                    Name = "Row " + i,
                    Children = new ObservableCollection<TreeData>()
                };

                for (int j = 0; j < 2; j++)
                {
                    TreeData n1 = new TreeData
                    {
                        ID = i + j,
                        Name = "Row " + i + " " + j,
                        Children = new ObservableCollection<TreeData>()
                    };
                   
                    n.Children.Add(n1);
                }

                data.Add(n);
            }

            return data;
        }
    }

    public class PropertyChangedNotifier : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        public void OnPropertyChagned(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }	

}
